@@ -27,7 +27,7 @@ export FULLPKG=${PKG}-${VER}-${REL}
 # if the orig src package is bzip2'ed, remember to
 # change 'z' to 'j' in the 'tar xvzf' commands in the
 # prep) and mkpatch) sections
-export src_orig_pkg_name=docbk41.zip
+export src_orig_pkg_name=docbook-4.2.zip
 export src_pkg_name=${FULLPKG}-src.tar.bz2
 export src_patch_name=${FULLPKG}.patch
 export bin_pkg_name=${FULLPKG}.tar.bz2
